# Tool Environment — {bot_name}

## Tool Notes

Use this file to describe environment-specific context for the tools available to you. This helps you use tools more effectively in {user_name}'s specific setup.

<!-- Examples:
- The "send_email" tool sends from {user_name}'s primary Gmail account.
- The "search_web" tool is rate-limited to 10 queries per hour.
- The "fetch_webpage" tool cannot access sites behind authentication.
-->
